==> haskell-pipes-4.3.16-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pipes
version:              4.3.16
visibility:           public
id:                   pipes-4.3.16-2NVQ4hSXcyX73NOm3M4VKF
key:                  pipes-4.3.16-2NVQ4hSXcyX73NOm3M4VKF
license:              BSD-3-Clause
copyright:            2012-2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components

    Advantages over traditional streaming libraries:

    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''

    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion

    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies

    * /Elegant semantics/: Use practical category theory

    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes

    * /Bidirectionality/: Implement duplex channels

    * /Extensive Documentation/: Second to none!

    Import "Pipes" to use the library.

    Read "Pipes.Tutorial" for an extensive tutorial.

category:             Control, Pipes
abi:                  c466b958e509672c357847d650189011
exposed:              True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pipes-4.3.16
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pipes-4.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes
hs-libraries:         HSpipes-4.3.16-2NVQ4hSXcyX73NOm3M4VKF
depends:
    base-4.16.4.0 exceptions-0.10.4 mmorph-1.2.0-86rQZSuTSAZIoeBosVXsFi
    mtl-2.2.2 transformers-0.5.6.2 void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:   /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html:         /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-4.3.16-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pipes
version:              4.3.16
visibility:           public
id:                   pipes-4.3.16-5WMmlN5d6YzCQYtZAutQIz
key:                  pipes-4.3.16-5WMmlN5d6YzCQYtZAutQIz
license:              BSD-3-Clause
copyright:            2012-2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components

    Advantages over traditional streaming libraries:

    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''

    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion

    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies

    * /Elegant semantics/: Use practical category theory

    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes

    * /Bidirectionality/: Implement duplex channels

    * /Extensive Documentation/: Second to none!

    Import "Pipes" to use the library.

    Read "Pipes.Tutorial" for an extensive tutorial.

category:             Control, Pipes
abi:                  b36bddefed34e17027227ceff36798c8
exposed:              True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pipes-4.3.16
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pipes-4.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes
hs-libraries:         HSpipes-4.3.16-5WMmlN5d6YzCQYtZAutQIz
depends:
    base-4.16.4.0 exceptions-0.10.4 mmorph-1.2.0-86rQZSuTSAZIoeBosVXsFi
    mtl-2.2.2 transformers-0.5.6.2 void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:   /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html:         /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
